@@ -67,6 +67,36 @@ class API(object):
             response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
         return response.json()
 
+    def modify_order(self, ticket, price, stoploss, takeprofit, expiration=0):
+        '''Open new order
+        
+        Parameters:
+        symbol: Symbol for trading,
+        cmd: Operation type: 0 = buy, 1 = sell, 2 = buylimit, 3 = buystop, 4 = selllimit, 5 = sellstop,
+        volume: Number of lots,
+        price: Order price,
+        slippage: Maximum price slippage for buy or sell orders,
+        stoploss: Stop loss level,
+        takeprofit: Take profit level,
+        comment: Order comment text,
+        
+        Returns:
+        dict: result of open order,
+        '''
+        if ticket<=0 or price <=0 or stoploss < 0 or takeprofit < 0 or expiration<0:
+            raise InputError('Invalid input(s)')
+        params = {"ticket":ticket,"price":price,"stoploss":stoploss,"takeprofit":takeprofit,"expiration":expiration}
+
+        link = self.domain + 'OrderModify'
+        
+        # print(self.token)
+        try:
+            response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
+        except:
+            time.sleep(1)
+            response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
+        return response.json()
+
     def close_order(self, ticket, lots = None, price = None):
         '''Close an existing order
         
